# ifndef CPPAD_CORE_FUN_EVAL_HPP
# define CPPAD_CORE_FUN_EVAL_HPP

/* --------------------------------------------------------------------------
CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell

CppAD is distributed under multiple licenses. This distribution is under
the terms of the
                    GNU General Public License Version 3.

A copy of this license is included in the COPYING file of this distribution.
Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
-------------------------------------------------------------------------- */

# include <cppad/core/forward.hpp>
# include <cppad/core/reverse.hpp>
# include <cppad/core/sparse.hpp>

# endif
